@@ -54,7 +54,7 @@ getGOGraph<-function(term, prune=Inf){
 	G
 }
 
-calcICs<-function(){	
+calcICs<-function(DIR="."){	
 	require(GO.db)
 	if(!require(annotate))
 		stop("Package annotate is required for function calcICs")
@@ -81,7 +81,7 @@ calcICs<-function(){
 	names(ta)<-ids	
 	IC<- -log(ta/sum(tab))	# ACHTUNG: hier muß tab und nicht ta stehen: Die Vorkommenshäufigkeit des Wurzelknotens ist die Summe der Vorkommenshäufigkeiten aller Knoten OHNE Aufsummieren der Kinder!
 # # 	IC[IC == Inf] = 0 # WRONG: GO terms which are not annotated have Inf information content (NOT 0: They cannot be treated like root!!!)
-	save(IC,file=paste("ICs",ontology,organism,paste(evidences,collapse="_"),".rda",sep=""))	
+	save(IC,file=file.path(DIR, paste("ICs",ontology,organism,paste(evidences,collapse="_"),".rda",sep="")))	
 	print("done")			
 }
 
